@@ -11,7 +11,7 @@ use Encode qw( decode );
 BEGIN {
 
 # ABSTRACT: Perl bindings to libarchive via XS
-our $VERSION = '0.06'; # VERSION
+our $VERSION = '0.07'; # VERSION
 
   unless($^O eq 'MSWin32')
   {
@@ -229,7 +229,7 @@ Archive::Libarchive::XS - Perl bindings to libarchive via XS
 
 =head1 VERSION
 
-version 0.06
+version 0.07
 
 =head1 SYNOPSIS
 
@@ -778,6 +778,15 @@ read:
  # or
  my $decoded_content = decode('KOI8-R', $raw);
 
+=head1 SUPPORT
+
+If you find bugs, please open an issue on the project GitHub repository:
+
+L<https://github.com/plicease/Archive-Libarchive-XS/issues?state=open>
+
+If you have a fix, please open a pull request.  You can see the CONTRIBUTING
+file for traps, hints and pitfalls.
+
 =head1 CAVEATS
 
 Archive and entry objects are really pointers to opaque C structures
